@@ -1,9 +1,15 @@
+//! # ksynth
+//!
+//! Patch manipulation helpers for Kawai digital synths.
+
 pub mod k5000;
 pub mod k4;
 
+/// Parsing and generating MIDI System Exclusive data.
 pub trait SystemExclusiveData {
     fn from_bytes(data: Vec<u8>) -> Self;
     fn to_bytes(&self) -> Vec<u8>;
+    fn data_size(&self) -> usize { 0 }
 }
 
 pub trait Checksum {
@@ -45,14 +51,6 @@ fn every_nth_byte(v: &Vec<u8>, n: usize, start: usize) -> Vec<u8> {
 mod tests {
     use super::*;
 
-    /*
-    #[test]
-    fn test_submix_name() {
-        let submix = effect::Submix::A;
-        assert_eq!(submix.name(), "A");
-    }
-    */
-
     #[test]
     fn test_every_nth_byte() {
         let data1 = vec![1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12];
